@@ -17,9 +17,8 @@ from c8connector import C8Connector, Sample, ConfigAttributeType, Schema
 from c8connector import ConfigProperty
 from joblib import Parallel, delayed, parallel_backend
 from jsonschema import Draft7Validator, FormatChecker
-from singer import get_logger
-
 from macrometa_target_postgres.db_sync import DbSync
+from singer import get_logger
 
 LOGGER = get_logger('macrometa_target_postgres')
 
@@ -27,7 +26,7 @@ DEFAULT_BATCH_SIZE_ROWS = 100000
 DEFAULT_PARALLELISM = 0  # 0 The number of threads used to flush tables
 DEFAULT_MAX_PARALLELISM = 16  # Don't use more than this number of threads by default when flushing streams in parallel
 DEFAULT_BATCH_FLUSH_INTERVAL = 60
-DEFAULT_MIN_BATCH_FLUSH_TIME_GAP = 120
+DEFAULT_MIN_BATCH_FLUSH_TIME_GAP = 60
 
 
 class PostgresTargetConnector(C8Connector):
@@ -70,54 +69,54 @@ class PostgresTargetConnector(C8Connector):
     def config(self) -> list[ConfigProperty]:
         """Get configuration parameters for the connector."""
         return [
-            ConfigProperty('host', ConfigAttributeType.STRING, True, False,
-                           description='PostgreSQL host',
-                           example='51.25.44.24'),
-            ConfigProperty('port', ConfigAttributeType.INT, True, False,
-                           description='PostgreSQL port',
-                           example='5432'),
-            ConfigProperty('user', ConfigAttributeType.STRING, True, False,
-                           description='PostgreSQL user',
-                           example='postgres'),
-            ConfigProperty('password', ConfigAttributeType.STRING, True, False,
-                           description='PostgreSQL password',
-                           example='password'),
-            ConfigProperty('dbname', ConfigAttributeType.STRING, True, False,
-                           description='PostgreSQL database name',
-                           example='postgres'),
-            ConfigProperty('batch_size_rows', ConfigAttributeType.INT, False, False,
-                           description='Maximum number of rows in each batch. At the end of each batch, '
-                                       'the rows in the batch are loaded into Postgres.',
-                           example='100000'),
-            ConfigProperty('batch_flush_interval', ConfigAttributeType.INT, False, False,
-                           description='Time interval between batch flush task executions in seconds.',
-                           example='60'),
-            ConfigProperty('batch_flush_min_time_gap', ConfigAttributeType.INT, False, False,
-                           description='Minimum time gap between two batch flush tasks in seconds.',
-                           example='120'),
-            ConfigProperty('flush_all_streams', ConfigAttributeType.BOOLEAN, False, False,
+            ConfigProperty('host', 'Host', ConfigAttributeType.STRING, True, False,
+                           description='PostgreSQL host.',
+                           placeholder_value='postgres_host'),
+            ConfigProperty('port', 'Port', ConfigAttributeType.INT, True, False,
+                           description='PostgreSQL port.',
+                           default_value='5432'),
+            ConfigProperty('user', 'Username', ConfigAttributeType.STRING, True, False,
+                           description='PostgreSQL user.',
+                           default_value='postgres'),
+            ConfigProperty('password', 'Password', ConfigAttributeType.STRING, True, False,
+                           description='PostgreSQL password.',
+                           placeholder_value='password'),
+            ConfigProperty('dbname', 'Database Name', ConfigAttributeType.STRING, True, False,
+                           description='PostgreSQL database name.',
+                           default_value='postgres'),
+            ConfigProperty('default_target_schema', 'Target Schema', ConfigAttributeType.STRING, True, False,
+                           description='Name of the schema where the tables will be created. If "schema_mapping" '
+                                       'is not defined then every stream is loaded into this schema.',
+                           placeholder_value='public'),
+            ConfigProperty('batch_size_rows', 'Batch Size', ConfigAttributeType.INT, False, False,
+                           description='Maximum number of rows inserted per batch.',
+                           default_value='100000'),
+            ConfigProperty('batch_flush_interval', 'Batch Flush Interval (Seconds)',
+                           ConfigAttributeType.INT, False, False,
+                           description='Time between batch flush executions.',
+                           default_value='60'),
+            ConfigProperty('batch_flush_min_time_gap', 'Batch Flush Minimum Time Gap (Seconds)',
+                           ConfigAttributeType.INT, False, False,
+                           description='Minimum time gap between two batch flush tasks.',
+                           default_value='60'),
+            ConfigProperty('flush_all_streams', 'Flush All Streams', ConfigAttributeType.BOOLEAN, False, False,
                            description='Flush and load every stream into Postgres when one batch is full. '
-                                       'Warning: This may trigger the COPY command to use files with low '
-                                       'number of records.',
-                           example='False'),
-            ConfigProperty('parallelism', ConfigAttributeType.INT, False, False,
-                           description='The number of threads used to flush tables. 0 will create a thread '
-                                       'for each stream, up to parallelism_max. -1 will create a thread for '
-                                       'each CPU core. Any other positive number will create that number of '
-                                       'threads, up to parallelism_max.',
-                           example='0'),
-            ConfigProperty('max_parallelism', ConfigAttributeType.INT, False, False,
-                           description='Max number of parallel threads to use when flushing tables.',
-                           example='16'),
-            ConfigProperty('default_target_schema', ConfigAttributeType.STRING, False, False,
-                           description='Name of the schema where the tables will be created. If `schema_mapping` '
-                                       'is not defined then every stream sent by the tap is loaded into this schema.',
-                           example='public'),
-            ConfigProperty('default_target_schema_select_permission', ConfigAttributeType.STRING, False, False,
-                           description='Grant USAGE privilege on newly created schemas and grant SELECT privilege '
-                                       'on newly created',
-                           example='SELECT'),
-            ConfigProperty('add_metadata_columns', ConfigAttributeType.BOOLEAN, False, False,
+                                       'This may trigger the COPY command to use files with low number of records.',
+                           default_value='False'),
+            ConfigProperty('parallelism', 'Parallelism', ConfigAttributeType.INT, False, False,
+                           description='Number of threads used to flush tables. "0" will create a thread for each '
+                                       'stream, up to parallelism_max. "-1" will create a thread for each CPU core. '
+                                       'Any other positive number will create that number of threads, up to '
+                                       'parallelism_max.',
+                           default_value='0'),
+            ConfigProperty('max_parallelism', 'Maximum Paralellism', ConfigAttributeType.INT, False, False,
+                           description='Maximum number of parallel threads used to flush tables.',
+                           default_value='16'),
+            ConfigProperty('default_target_schema_select_permission', 'Targert Schema Privileges',
+                           ConfigAttributeType.STRING, False, False,
+                           description='Grant privileges to newly created schemas. Choose from USAGE, SELECT.',
+                           placeholder_value='SELECT'),
+            ConfigProperty('add_metadata_columns', 'Add Metadata Columns', ConfigAttributeType.BOOLEAN, False, False,
                            description='Metadata columns add extra row level information about data ingestions, '
                                        '(i.e. when was the row read in source, when was inserted or deleted in '
                                        'postgres etc.) Metadata columns are creating automatically by adding extra '
@@ -125,32 +124,33 @@ class PostgresTargetConnector(C8Connector):
                                        'following the stitch naming conventions documented at '
                                        'https://www.stitchdata.com/docs/data-structure/integration-schemas#sdc-columns '
                                        'Enabling metadata columns will flag the deleted rows by setting the '
-                                       '`_SDC_DELETED_AT` metadata column. Without the `add_metadata_columns` '
-                                       'option the deleted rows from singer taps will not be recognisable in Postgres.',
-                           example='False'),
-            ConfigProperty('hard_delete', ConfigAttributeType.BOOLEAN, False, False,
+                                       '`_SDC_DELETED_AT` metadata column. Without the `add_metadata_columns` option '
+                                       'the deleted rows from singer taps will not be recognisable in Postgres.',
+                           default_value='false'),
+            ConfigProperty('hard_delete', 'Hard Delete', ConfigAttributeType.BOOLEAN, False, False,
                            description='When `hard_delete` option is true then DELETE SQL commands will be performed '
                                        'in Postgres to delete rows in tables. It is achieved by continuously checking '
-                                       'the  `_SDC_DELETED_AT` metadata column sent by the singer tap. Due to deleting '
-                                       'rows requires metadata columns, `hard_delete` option automatically enables the '
-                                       '`add_metadata_columns` option as well.',
-                           example='False'),
-            ConfigProperty('data_flattening_max_level', ConfigAttributeType.INT, False, False,
+                                       'the `_SDC_DELETED_AT` metadata column sent by the singer tap. Due to deleting '
+                                       'rows requires metadata columns, `hard_delete` option automatically enables the'
+                                       ' `add_metadata_columns` option as well.',
+                           default_value='false'),
+            ConfigProperty('data_flattening_max_level', 'Data Flattening Maximum Level', ConfigAttributeType.INT, False,
+                           False,
                            description='Object type RECORD items from taps can be transformed to flattened columns by '
                                        'creating columns automatically.<br><br>When value is 0 (default) then '
                                        'flattening functionality is turned off.',
-                           example='0'),
-            ConfigProperty('primary_key_required', ConfigAttributeType.BOOLEAN, False, False,
+                           default_value='0'),
+            ConfigProperty('primary_key_required', 'Primary Key Required', ConfigAttributeType.BOOLEAN, False, False,
                            description='Log based and Incremental replications on tables with no Primary Key cause '
                                        'duplicates when merging UPDATE events. When set to true, stop loading data '
                                        'if no Primary Key is defined.',
-                           example='True'),
-            ConfigProperty('validate_records', ConfigAttributeType.BOOLEAN, False, False,
+                           default_value='true'),
+            ConfigProperty('validate_records', 'Validate Records', ConfigAttributeType.BOOLEAN, False, False,
                            description='Validate every single record message to the corresponding JSON schema. '
-                                       'This option is disabled by default and invalid RECORD messages will fail '
-                                       'only at load time by Postgres. Enabling this option will detect invalid '
-                                       'records earlier but could cause performance degradation.',
-                           example='False'),
+                                       'This option is disabled by default and invalid RECORD messages will fail only '
+                                       'at load time by Postgres. Enabling this option will detect invalid records '
+                                       'earlier but could cause performance degradation.',
+                           default_value='false'),
         ]
 
     def capabilities(self) -> list[str]:
